<?php

/*
 * Load TGM Plugin
 */

require_once locate_template('/smart-lib/vendor/tgm/class-tgm-plugin-activation.php');

/**
 * Redirect after theme activation
 */

global $pagenow;

if (is_admin() && 'themes.php' == $pagenow && isset($_GET['activated'])) {

    wp_redirect(admin_url("themes.php?page=bootframe_activation")); // Your admin page URL

}

/*
 * Register smartlib activation function
 */
add_action('admin_menu', 'smartlib_theme_activation_options');

/*
 * Create the function that build menu
 */

function smartlib_theme_activation_options()
{
    add_theme_page(__('Bootframe Activation', 'bootframe'), __('Bootframe Activation', 'bootframe'), 'manage_options', 'bootframe_activation', 'smartlib_activation_display');
}

/*
 * Create a function that displays the contents of the options page
 */

function smartlib_activation_display()
{
    if (!current_user_can('manage_options')) {
        wp_die(__('You do not have sufficient permissions to access this page.', 'bootframe'));
    }





    ?>
    <div class="wrap">
        <h2><?php _e('BootFrame Activation', 'bootframe') ?></h2>

        <div class="welcome-panel">
            <div class="smartlib-welcome-text">
                <h1><?php _e('Congratulations! BootFrame is working now!', 'bootframe') ?></h1>

                <p class="about-description"><?php _e('If you want to enjoy all the options offered by the theme you need to install all plugins listed below:', 'bootframe') ?></p>

            </div>
            <div class="welcome-panel-column" style="width: 50%">
                <h4><?php _e('Plugins List', 'bootframe') ?></h4>

                <div class="smartlib-plugin-requirments-area">

                    <table class="wp-list-table widefat">
                        <thead>
                        <tr>
                            <th class="column-name"><?php _e('Plugin Name', 'bootframe');?></th>
                            <th class="column-description"><?php _e('Why You should install it?', 'bootframe');?></th>

                        </tr>
                        </thead>
                        <tbody>
                        <tr>
                            <td class="column-name"><strong><?php _e('Page Builder by SiteOrigin', 'bootframe');?></strong></td>
                            <td class="column-description"><?php _e('A drag and drop, responsive page builder that simplifies
                                building your website.', 'bootframe');?>
                            </td>

                        </tr>
                        <tr>
                            <td class="column-name"><strong><?php _e('Smartlib Tools', 'bootframe');?></strong></td>
                            <td class="column-description"><?php _e('Some extra features to your theme: Portfolio, Testimonials,
                                FAQ and Team Members Post Types.', 'bootframe');?>
                            </td>

                        </tr>
                        <tr>
                            <td class="column-name"><strong><?php _e('Meta Slider', 'bootframe');?></strong></td>
                            <td class="column-description"><?php _e('Easy to use slideshow plugin. Create SEO optimised responsive
                                slideshows with Nivo Slider, Flex Slider, Coin Slider and Responsive Slides.', 'bootframe');?>
                            </td>

                        </tr>
                        <tr>
                            <td class="column-name"><strong><?php _e('Shortcodes Ultimate', 'bootframe');?></strong></td>
                            <td class="column-description"><?php _e('Supercharge your WordPress theme with mega pack of
                                shortcodes', 'bootframe');?>
                            </td>

                        </tr>


                        <tr>
                            <td class="column-name"><strong><?php _e('Contact Form 7', 'bootframe');?></strong></td>
                            <td class="column-description"><?php _e('Contact Form 7 can manage multiple contact forms, plus you
                                can customize the form and the mail contents flexibly with simple markup.', 'bootframe');?>
                            </td>

                        </tr>




                        </tbody>
                    </table>
                    <p>
                        <?php
                        if (smartlib_check_if_install_plugin_exists()){
                        ?>
                        <a href="themes.php?page=tgmpa-install-plugins" class="button button-primary button-hero"><?php _e('Go to plugins activation panel', 'bootframe') ?></a></p>
                    <?php
                    }

                    ?>


                </div>
            </div>
        </div>
        <div class="welcome-panel">
            <h2><?php _e('Need extensive documentation and theme support? Learn more about BootFrame Premium!', 'bootframe') ?></h2>

            <p class="about-description"><a href="https://creativemarket.com/netbiel/341968-BootFrame-WordPress-theme" target="_blank">BootFrame Premium</a> <?php _e('adds exciting new customization features to the Customizer and other powerful customization tools like shortcodes or layout options.', 'bootframe') ?></p>

            <p><a href="https://creativemarket.com/netbiel/341968-BootFrame-WordPress-theme" class="button button-primary button-hero" target="_blank"><?php _e('More Info', 'bootframe') ?> &raquo;</a></p></p>
        </div>
    </div>
<?php }


/**
 * TGMPA PLugin Register Function
 */
function smartlib_activation_setup()
{

    add_action('tgmpa_register', 'smartlib_theme_register_required_plugins');
}

add_action('after_setup_theme', 'smartlib_activation_setup');


/**
 * Register the required plugins for this theme.
 *
 * In this example, we register two plugins - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to bootframe_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into bootframe_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function smartlib_theme_register_required_plugins()
{

    /**
     * Array of plugin arrays. Required keys are name and slug.
     * If the source is NOT from the .org repo, then source is also required.
     */
    $plugins = array(

        // This is an example of how to include a plugin pre-packaged with a theme.
        array(
            'name' => 'Page Builder by SiteOrigin', // The plugin name.
            'slug' => 'siteorigin-panels', // The plugin slug (typically the folder name).
            'source' => get_stylesheet_directory() . '/vendor/plugins/siteorigin-panels.zip', // The plugin source.
            'required' => true, // If false, the plugin is only 'recommended' instead of required.
            'version' => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
            'force_activation' => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
            'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
            'external_url' => '', // If set, overrides default API URL and points to an external URL.
        ),

        array(
            'name' => 'Smartlib Tools', // The plugin name.
            'slug' => 'smartlib-tools', // The plugin slug (typically the folder name).
            'source' => get_stylesheet_directory() . '/vendor/plugins/smartlib-tools.zip', // The plugin source.
            'required' => true, // If false, the plugin is only 'recommended' instead of required.
            'version' => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
            'force_activation' => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
            'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
            'external_url' => '', // If set, overrides default API URL and points to an external URL.
        ),

        array(
            'name' => 'Meta Slider', // The plugin name.
            'slug' => 'ml-slider', // The plugin slug (typically the folder name).
            'source' => get_stylesheet_directory() . '/vendor/plugins/ml-slider.zip', // The plugin source.
            'required' => true, // If false, the plugin is only 'recommended' instead of required.
            'version' => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
            'force_activation' => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
            'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
            'external_url' => '', // If set, overrides default API URL and points to an external URL.
        ),

        array(
            'name' => 'Shortcodes Ultimate', // The plugin name.
            'slug' => 'shortcodes-ultimate', // The plugin slug (typically the folder name).
            'source' => get_stylesheet_directory() . '/vendor/plugins/shortcodes-ultimate.zip', // The plugin source.
            'required' => true, // If false, the plugin is only 'recommended' instead of required.
            'version' => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
            'force_activation' => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
            'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
            'external_url' => '', // If set, overrides default API URL and points to an external URL.
        ),


        array(
            'name' => 'Contact Form 7', // The plugin name.
            'slug' => 'contact-form-7', // The plugin slug (typically the folder name).
            'source' => get_stylesheet_directory() . '/vendor/plugins/contact-form-7.zip', // The plugin source.
            'required' => false, // If false, the plugin is only 'recommended' instead of required.
            'version' => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
            'force_activation' => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
            'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
            'external_url' => '', // If set, overrides default API URL and points to an external URL.
        ),




    );

    /**
     * Array of configuration settings. Amend each line as needed.
     * If you want the default strings to be available under your own theme domain,
     * leave the strings uncommented.
     * Some of the strings are added into a sprintf, so see the comments at the
     * end of each line for what each argument will be.
     */
    $config = array(
        'id' => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
        'menu' => 'tgmpa-install-plugins', // Menu slug.
        'has_notices' => true,                    // Show admin notices or not.
        'dismissable' => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg' => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => true,                   // Automatically activate plugins after installation or not.
        'message' => '',                      // Message to output right before the plugins table.
        'strings' => array(
            'page_title' => __('Install Required Plugins', 'bootframe'),
            'menu_title' => __('Install Plugins', 'bootframe'),
            'installing' => __('Installing Plugin: %s', 'bootframe'), // %s = plugin name.
            'oops' => __('Something went wrong with the plugin API.', 'bootframe'),
            'notice_can_install_required' => _n_noop('This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'bootframe'), // %1$s = plugin name(s).
            'notice_can_install_recommended' => _n_noop('This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'bootframe'), // %1$s = plugin name(s).
            'notice_cannot_install' => _n_noop('Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'bootframe'), // %1$s = plugin name(s).
            'notice_can_activate_required' => _n_noop('The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'bootframe'), // %1$s = plugin name(s).
            'notice_can_activate_recommended' => _n_noop('The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'bootframe'), // %1$s = plugin name(s).
            'notice_cannot_activate' => _n_noop('Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'bootframe'), // %1$s = plugin name(s).
            'notice_ask_to_update' => _n_noop('The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'bootframe'), // %1$s = plugin name(s).
            'notice_cannot_update' => _n_noop('Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'bootframe'), // %1$s = plugin name(s).
            'install_link' => _n_noop('Begin installing plugin', 'Begin installing plugins', 'bootframe'),
            'activate_link' => _n_noop('Begin activating plugin', 'Begin activating plugins', 'bootframe'),
            'return' => __('Return to Required Plugins Installer', 'bootframe'),
            'plugin_activated' => __('Plugin activated successfully.', 'bootframe'),
            'complete' => __('All plugins installed and activated successfully. %s', 'bootframe'), // %s = dashboard link.
            'nag_type' => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
        )
    );

    tgmpa($plugins, $config);

}


/**
 *
 * Check if display install plugins menu
 *
 * @return bool
 */
function smartlib_check_if_install_plugin_exists()
{
    if (isset($GLOBALS['submenu'])) {
        foreach ($GLOBALS['submenu'] as $level1) {
            foreach ($level1 as $level2) {
                if (in_array('tgmpa-install-plugins', $level2)) {
                    return true;
                }
            }
        }
    }

    return false;
}


?>